@@ -1,13 +1,21 @@
 # -*- coding: utf-8 -*-
 from mvvmQt.rewriteContorls import Widget, Window, Label
-from PyQt5.QtWidgets import QWidget, QFrame, QPushButton, QGridLayout, QLayout, QHBoxLayout, QVBoxLayout, QLabel, QTabWidget\
-    , QStatusBar, QButtonGroup, QAbstractButton, QRadioButton, QComboBox
+from PyQt5.QtWidgets import QWidget, QFrame, QPushButton, QGridLayout, QLayout, QHBoxLayout, QVBoxLayout, QTabWidget\
+    , QStatusBar, QButtonGroup, QAbstractButton, QRadioButton, QComboBox, QTextEdit
 from mvvmQt.Observable import ObservableBase
 import asyncio
 
-class RowOrCol:
+class Row:
     def __init__(self, e):
         self.e = e
+        self.num = 0 #行号
+        self.span = 1 #跨行
+        self.offset = 0 #偏移
+
+class Col:
+    def __init__(self, e):
+        self.e = e
+        self.num = 0 #列号
 
     @property
     def offset(self):
@@ -15,15 +23,15 @@ class RowOrCol:
 
     @property
     def span(self):
-        return int(self.e.attrsToDict.get('span', 0))
+        return int(self.e.attrsToDict.get('span', 1))
 
-class Row(RowOrCol):
-    def __init__(self, e):
-        super().__init__(e)
+    @property
+    def rowSpan(self):
+        return int(self.e.attrsToDict.get('rowSpan', 1))
 
-class Col(RowOrCol):
-    def __init__(self, e):
-        super().__init__(e)
+    @property
+    def rowOffset(self):
+        return int(self.e.attrsToDict.get('rowOffset', 0))
 
 class Element:
     def __init__(self, parser, parent, name, dom):
@@ -54,13 +62,15 @@ class Element:
             'tab': [self.createTab, self.afterCreateTab],
             'select': [self.createCombo, self.afterCreateCombo],
             'option': [self.createOption, None],
-            'status': [self.createStatusBar, self.bindAll]
+            'status': [self.createStatusBar, self.bindAll],
+            'text-edit': [self.createTextEdit, self.bindAll]
         }
 
-        self.create()
-
     def create(self):
-        self.useFunc[self.name][0]()
+        if self.name in self.useFunc.keys():
+            self.useFunc[self.name][0]()
+            return True
+        return False
 
     def make(self):
         if self.useFunc[self.name][1]:
@@ -145,11 +155,15 @@ class Element:
                 return o.parent.qt
             o = o.parent
 
+    def checkReload(self, defaultClass):
+        reload = self.dom.attr('reload')
+        return self.parser.qtClass[reload]() if reload else defaultClass()
+
     def createWindow(self):
-        self.qt = Window()
+        self.qt = self.checkReload(Window)
 
     def createWidget(self):
-        self.qt = Widget()
+        self.qt = self.checkReload(Widget)
 
     def createFrame(self):
         self.qt = QFrame(self.parent.qt if self.parent.name in self.topWidget else None)
@@ -173,31 +187,32 @@ class Element:
     def afterCreateGridLayout(self):
         self.bindAttr()
         es = []
-        row_num = 0
-        for row in filter(lambda c: type(c.qt) is Row, self.childs):
-            row = row.qt
-            col_num = 0
+        rows = list(filter(lambda c: type(c.qt) is Row, self.childs))
+        for i in range(len(rows)):
+            row = rows[i].qt
+            if i > 0:
+                pre_row = rows[i - 1].qt
+                row.num = pre_row.num + pre_row.span #行号等于上一行的行号+跨行数
             cols = list(filter(lambda c: type(c.qt) is Col, row.e.childs))
             if len(cols) == 0:
                 continue
-            row_num += row.offset
-            row_span_add = 0
-            for col in cols:
-                col = col.qt
+            for j in range(len(cols)):
+                col = cols[j].qt
+                if j > 0:
+                    pre_col = cols[j - 1].qt
+                    col.num = pre_col.num + pre_col.span
+
+                if row.span + row.num < col.rowSpan + col.rowOffset + row.num:
+                    #跨行数根据行号 + 行号 + 偏移来判断大小
+                    row.span = col.rowSpan + col.rowOffset
+
                 if len(col.e.childs) == 0:
                     continue
-                col_num += col.offset
-                if row.span > 0 or col.span > 0:
-                    rowSpan = row.span or 1
-                    colSpan = col.span or 1
-                    row_span_add += rowSpan - 1
-                    es.append([col.e.childs[0].qt, row_num, col_num, rowSpan, colSpan])
-                    col_num += colSpan - 1
-                else:
-                    es.append([col.e.childs[0].qt, row_num, col_num])
-                col_num += 1
-            row_num += 1
-            row_num += row_span_add
+                # if row.span > 1 or col.span > 1:
+                #     es.append([col.e.childs[0].qt, row.num, col.num, row.span, col.span])
+                # else:
+                #     es.append([col.e.childs[0].qt, row.num, col.num])
+                es.append([col.e.childs[0].qt, row.num + col.rowOffset, col.num + col.offset, col.rowSpan, col.span])
 
         for e in es:
             if isinstance(e[0], QLayout):
@@ -290,4 +305,7 @@ class Element:
         self.isVitrual = True
 
     def createStatusBar(self):
-        self.qt = QStatusBar()
\ No newline at end of file
+        self.qt = QStatusBar()
+
+    def createTextEdit(self):
+        self.qt = QTextEdit()
\ No newline at end of file
