@@ -22,12 +22,16 @@ class Parser:
     def __init__(self, src, tempDir='templates', indexName='index', obj={}, models=None, events=None):
         self.env = Environment(loader=FileSystemLoader(searchpath=os.path.join(src, tempDir), encoding='utf-8'))
         self.obj = obj
+        self.qtClass = {} #重载的Qt类，build的时候发现有特殊指定会使用重新定义的类来覆盖原有的类
         self.indexName = indexName
         self.elements = [] #元素列表
         self.btnGroups = {} #按键组
         self.models = models
         self.events = events
 
+    def addQtClass(self, name, obj): #必须在build之前使用才有效
+        self.qtClass[name] = obj
+
     def create_loop(self):
         self.loop = QEventLoop(self.app)
         asyncio.set_event_loop(self.loop)
@@ -47,6 +51,10 @@ class Parser:
             if 'id' in e.attrsToDict.keys():
                 self.idElements[e.attrsToDict['id']] = e
 
+    # 重载指定元素的qt的事件
+    # id为元素的id
+    # name为事件名
+    # func为重载后的事件方法，参考event example
     def reloadEvent(self, id, name, func):
         obj = self.idElements[id]
         setattr(obj.qt, name, types.MethodType(func(), getattr(obj, 'qt')))
@@ -80,7 +88,7 @@ class Parser:
 
     def loopChild(self, e, parent=None):
         dom = pq(e)
-        tagName = self.tagName(dom)
+        tagName = self.tagName(dom).strip('/')
         #检查是否为属性设置
         if tagName.startswith('attr'):
             ob_value = dom.attr('ob')
@@ -111,11 +119,15 @@ class Parser:
             return self.EventObj(tagName.replace('event-', ''), param, f)
 
         e = self.ElementObj(self, parent, tagName, dom)
+        if not e.create():
+            return False
         l = list(map(lambda c: self.loopChild(c, e), dom.children()))
         attrs = []
         events = []
         childs = []
         for c in l:
+            if not c:
+                continue
             if type(c) is self.AttributeObj:
                 attrs.append(c)
             elif type(c) is self.EventObj:
