@@ -81,6 +81,10 @@ ElementAttr = {
     },
     'select': {
         'index': ['setCurrentIndex', int]
+    },
+    'text-edit': {
+        'text': [f.textChanged, None],
+        'html': [f.htmlChanged, None]
     }
 }
 
